"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const extract_1 = require("@code-dependency/extract");
const resolver_1 = require("@code-dependency/resolver");
const path = require("path");
const gather_1 = require("./gather");
const stripBasePath = (from, to) => {
    return to.startsWith(from) ? path.relative(from, to) : to;
};
const getDependencies = async (options, resolveOption) => {
    const visited = new Set();
    const allFiles = await gather_1.gather(options);
    return allFiles.reduce((previousSourceDependencies, source) => {
        if (visited.has(source)) {
            return previousSourceDependencies;
        }
        visited.add(source);
        const dependencies = extract_1.getTsDependencies(source).map((extractObject) => {
            const attributes = resolver_1.addResolutionAttribute({ baseDir: options.executeDirectory }, source, resolveOption)({
                moduleName: extractObject.module,
                moduleSystem: extractObject.moduleSystem,
            });
            attributes.resolved =
                attributes.resolved && options.stripBasePath ? stripBasePath(options.stripBasePath, attributes.resolved) : undefined;
            return attributes;
        });
        const result = {
            source: options.stripBasePath ? stripBasePath(options.stripBasePath, source) : source,
            dependencies,
        };
        return previousSourceDependencies.concat(result);
    }, []);
};
exports.getDependencies = getDependencies;
